@@ -10,7 +10,7 @@ use Dumpvalue;
 use version ();
 use File::Spec ();
 
-our $VERSION = '0.40';
+our $VERSION = '0.42';
 our $VERBOSE = 0;
 our $ALLOW_DEV_VERSION = 0;
 our $FORK = 0;
@@ -377,7 +377,8 @@ sub _packages_per_pmfile {
         if (
             $pline =~ m{
                       # (.*) # takes too much time if $pline is long
-                      (?<![*\$\\@%&]) # no sigils
+                      #(?<![*\$\\@%&]) # no sigils
+                      ^[\s\{;]*
                       \bpackage\s+
                       ([\w\:\']+)
                       \s*
@@ -397,7 +398,7 @@ sub _packages_per_pmfile {
             # Found something
 
             # from package
-            $pkg =~ s/\'/::/;
+            $pkg =~ s/\'/::/g;
             next PLINE unless $pkg =~ /^[A-Za-z]/;
             next PLINE unless $pkg =~ /\w$/;
             next PLINE if $pkg eq "main";
